[jira] Rewrite all known Jira ids to monorail ids.

Bug: 60389

Change-Id: Ic4e746ad27bd3f68c7efafeaa83f59f1d308cd61
Reviewed-on: https://fuchsia-review.googlesource.com/c/experiences/+/431554
Reviewed-by: Chase Latta <chaselatta@google.com>
Testability-Review: Chase Latta <chaselatta@google.com>
Commit-Queue: Nathan Mulcahey <nmulcahey@google.com>
diff --git a/examples/localized_flutter/localized_flutter_app/lib/main.dart b/examples/localized_flutter/localized_flutter_app/lib/main.dart
index 8a634b4..7bfefca 100644
--- a/examples/localized_flutter/localized_flutter_app/lib/main.dart
+++ b/examples/localized_flutter/localized_flutter_app/lib/main.dart
@@ -15,7 +15,7 @@
   final providers = Providers()..provideValue(CurrentLocale(null));
 
   runApp(ProviderNode(providers: providers, child: LocalizedMod()));
-  // TODO(FL-157): Receive i18n settings from the View interface.
+  // TODO(fxbug.dev/8745): Receive i18n settings from the View interface.
 }
 
 /// The main application widget for Localized Mod.
diff --git a/examples/localized_flutter/localized_flutter_localization/lib/README.md b/examples/localized_flutter/localized_flutter_localization/lib/README.md
index e608e3d..2378a9c 100644
--- a/examples/localized_flutter/localized_flutter_localization/lib/README.md
+++ b/examples/localized_flutter/localized_flutter_localization/lib/README.md
@@ -43,4 +43,4 @@
 These are checked into the repo _only as a temporary workaround_.
 
 In the future, there should be a GN build rule that will generate these code
-files at build time, so as to not pollute the source tree (FL-162).
+files at build time, so as to not pollute the source tree (fxbug.dev/8750).
diff --git a/settings/lib/widgets/lib/src/utils/deprecate.dart b/settings/lib/widgets/lib/src/utils/deprecate.dart
index a74e936..2d80868 100644
--- a/settings/lib/widgets/lib/src/utils/deprecate.dart
+++ b/settings/lib/widgets/lib/src/utils/deprecate.dart
@@ -2,7 +2,7 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 /// WARNING(MS-1613): to support a clean separation of concerns Flutter widgets
 /// will no longer depend the Fuchsia system (even transitively). Instead system
 /// interactions should be coupled to a Flutter application by authors directly
 /// using either the ModuleDriver (//topaz/public/lib/app_driver) or the raw,
@@ -12,10 +12,10 @@
 import 'package:fuchsia_logger/logger.dart';
 
 /// Adds a logger message about the impending deprecation of a given class or
-/// method related to MS-1613.
+/// method related to fxbug.dev/15214.
 void deprecate(String name) {
   log.warning(
-      '''"$name" is deprecated, see MS-1613 for context. Some suggestions
+      '''"$name" is deprecated, see fxbug.dev/15214 for context. Some suggestions
 * System interactions: use //topaz/public/lib/app_driver/dart or the raw Dart FIDL bindings.
 * App state: use 'package:lib.widgets/model.dart' directly or 'package:scoped_model/model.dart' when it's avaialble.
 * Model access in widget tree: use 'package:lib.widgets/model.dart' or 'package:scoped_model/model.dart' when it's avaialble.
@@ -2,7 +2,7 @@
 // found in the LICENSE file.
 
-/// WARNING(MS-1613): to support a clean separation of concerns Flutter widgets
+/// WARNING(fxbug.dev/15214): to support a clean separation of concerns Flutter widgets
 /// will no longer depend the Fuchsia system (even transitively). Instead system
 /// interactions should be coupled to a Flutter application by authors directly